Index: chrome/browser/resources/shared/js/cr/ui/list.js |
diff --git a/chrome/browser/resources/shared/js/cr/ui/list.js b/chrome/browser/resources/shared/js/cr/ui/list.js |
index 33a984ebf5e87e3565666798f8bf9ca90a2343d6..069744179f0e0c9cfafa04b197b7e2c79b25ee35 100644 |
--- a/chrome/browser/resources/shared/js/cr/ui/list.js |
+++ b/chrome/browser/resources/shared/js/cr/ui/list.js |
@@ -223,12 +223,14 @@ cr.define('cr.ui', function() { |
}, |
/** |
* The HTML elements representing the items. This is just all the element |
* children but subclasses may override this to filter out certain elements. |
* @type {HTMLCollection} |
*/ |
get items() { |
- return this.children; |
+ return Array.prototype.filter.call(this.children, function(child) { |
+ return !child.classList.contains('spacer'); |
+ }); |
}, |
batchCount_: 0, |
@@ -223,12 +223,14 @@ cr.define('cr.ui', function() { |
}, |
/** |
- * The HTML elements representing the items. This is just all the element |
+ * The HTML elements representing the items. This is just all the list item |
* children but subclasses may override this to filter out certain elements. |
* @type {HTMLCollection} |